@@ -1,5 +1,5 @@
 /*
- * "$Id: print-color.c,v 1.135 2006/05/28 16:59:04 rlk Exp $"
+ * "$Id: print-color.c,v 1.135.8.2 2007/12/15 20:35:45 rlk Exp $"
  *
  *   Gutenprint color management module - traditional Gutenprint algorithm.
  *
@@ -657,7 +657,7 @@ stpi_color_traditional_get_row(stp_vars_t *v,
   const lut_t *lut = (const lut_t *)(stp_get_component_data(v, "Color"));
   unsigned zero;
   if (stp_image_get_row(image, lut->in_data,
-			lut->image_width * lut->in_channels, row)
+			lut->image_width * lut->in_channels * lut->channel_depth / 8, row)
       != STP_IMAGE_STATUS_OK)
     return 2;
   if (!lut->channels_are_initialized)
@@ -785,6 +785,8 @@ compute_gcr_curve(const stp_vars_t *vars)
     k_trans = stp_get_float_parameter(vars, "BlackTrans");
   k_upper *= lut->steps;
   k_lower *= lut->steps;
+  stp_dprintf(STP_DBG_LUT, vars, " k_lower %.3f\n", k_lower);
+  stp_dprintf(STP_DBG_LUT, vars, " k_upper %.3f\n", k_upper);
 
   if (k_lower > lut->steps)
     k_lower = lut->steps;
