@@ -1,5 +1,5 @@
 /*
- * "$Id: print-util.c,v 1.109.4.1 2007/03/02 12:01:31 rlk Exp $"
+ * "$Id: print-util.c,v 1.109.4.4 2007/12/15 20:35:49 rlk Exp $"
  *
  *   Print plug-in driver utility functions for the GIMP.
  *
@@ -342,12 +342,20 @@ stp_dprintf(unsigned long level, const stp_vars_t *v, const char *format, ...)
 {
   int bytes;
   stpi_init_debug();
-  if ((level & stpi_debug_level) && stp_get_errfunc(v))
+  if (level & stpi_debug_level)
     {
-      char *result;
-      STPI_VASPRINTF(result, bytes, format);
-      (stp_get_errfunc(v))((void *)(stp_get_errdata(v)), result, bytes);
-      stp_free(result);
+      if (stp_get_errfunc(v))
+	{
+	  char *result;
+	  STPI_VASPRINTF(result, bytes, format);
+	  (stp_get_errfunc(v))((void *)(stp_get_errdata(v)), result, bytes);
+	  stp_free(result);
+	} else {
+	  va_list args;
+	  va_start(args, format);
+	  vfprintf(stderr, format, args);
+	  va_end(args);
+	}
     }
 }
 
@@ -459,9 +467,15 @@ stp_init(void)
     {
       /* Things that are only initialised once */
       /* Set up gettext */
+#ifdef HAVE_LOCALE_H
+      char *locale = stp_strdup(setlocale (LC_ALL, ""));
+#endif
 #ifdef ENABLE_NLS
-      setlocale (LC_ALL, "");
       bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+#endif
+#ifdef HAVE_LOCALE_H
+      setlocale(LC_ALL, locale);
+      stp_free(locale);
 #endif
       stpi_init_debug();
       stp_xml_preinit();
@@ -577,6 +591,8 @@ stp_merge_printvars(stp_vars_t *user, const stp_vars_t *print)
   int i;
   stp_parameter_list_t params = stp_get_parameter_list(print);
   int count = stp_parameter_list_count(params);
+  stp_deprintf(STP_DBG_VARS, "Merging printvars from %s\n",
+	       stp_get_driver(print));
   for (i = 0; i < count; i++)
     {
       const stp_parameter_t *p = stp_parameter_list_param(params, i);
@@ -610,6 +626,7 @@ stp_merge_printvars(stp_vars_t *user, const stp_vars_t *print)
 	  stp_parameter_description_destroy(&desc);
 	}
     }
+  stp_deprintf(STP_DBG_VARS, "Exiting merge printvars\n");
   stp_parameter_list_destroy(params);
 }
 
